<?php
// Let child theme modify template structure
do_action( 'hootbiz_theme_frontpage' );

// Loads the header.php template.
get_header();

// Template structure
$hootbiz_fpg_sidebar = apply_filters( 'hootbiz_theme_frontpage_sidebar', 'none' );
$hootbiz_fpg_content_context = ( $hootbiz_fpg_sidebar == 'none' ) ? 'none' : '';
$hootbiz_fpg_content_grid = ( $hootbiz_fpg_sidebar == 'none' ) ? 'hgrid-stretch' : 'hgrid';

// Template modification Hook
do_action( 'hootbiz_theme_before_content_grid', 'frontpage.php' );
?>

<div id="frontpage-wrap" class="<?php echo $hootbiz_fpg_content_grid; ?>">

	<?php
	// Template modification Hook
	do_action( 'hootbiz_theme_before_main', 'frontpage.php' );
	?>

	<main <?php hootbiz_attr( 'frontpage-content', $hootbiz_fpg_content_context ); ?>>

		<?php
		// Template modification Hook
		do_action( 'hootbiz_theme_main_start', 'frontpage.php' );

		// Display Header Image
		if ( get_header_image() ) :
			?><div id="header-image" class="hgrid-stretch">
				<img src="<?php header_image(); ?>" width="<?php echo absint( get_custom_header()->width ); ?>" height="<?php echo absint( get_custom_header()->height ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
			</div><?php
		endif;

		// Get Sections List
		$sections = hootbiz_sortlist( hootbiz_get_mod( 'frontpage_sections' ) );

		// Display Each Section according to ther sort order.
		if ( is_array( $sections ) && !empty( $sections ) ) :
			foreach ( $sections as $key => $section ) :
				if ( empty( $section[ 'sortitem_hide' ] ) ):

					// Set section type / context
					$context = ( strpos( $key, 'area_' ) === 0 ) ? str_replace( 'area_', '', $key ) : '';
					if ( ! empty( $context ) )
						$type = 'widgetarea';
					elseif ( $key == 'content' )
						$type = ( is_home() ) ? 'content-blog' : 'content-page';
					else
						$type = $key;
					$type = apply_filters( 'hootbiz_theme_frontpage_sections_switch', $type, $key, $sections );

					// Exit the loop except main content for a paged post list (blog)
					if ( $type != 'content-blog' && apply_filters( 'hootbiz_theme_paged_frontpage_hidemodules', is_paged() ) )
						continue;

					// Set section background
					$module_bg = hootbiz_get_mod( "frontpage_sectionbg_{$key}-type" );
					$module_bg = ( empty( $module_bg ) ) ? 'none' : $module_bg;
					$section_class = 'module-bg-' . $module_bg;
					$section_class .= ( $module_bg == 'highlight' ) ? ' area-highlight' : '';
					$section_class .= ( !empty( $section['grid'] ) && $section['grid'] == 'stretch' ) ? ' frontpage-area-stretch' : ' frontpage-area-boxed';

					// Allow child themes to have templates
					$custom_template = hootbiz_get_template_part( 'front-page-' . $key, $context );
					if ( $custom_template ):
						include( $custom_template );
					else:

						switch( $type ):

							// Display Widget Areas
							case 'widgetarea':
								$areakey = 'area_' . $context;
								$section['columns'] = isset( $section['columns'] ) ? $section['columns'] : '100';
								$structure = hootbiz_theme_get_column_span( $section['columns'] );
								$count = count( $structure );
								$displayarea = false;
								for ( $c = 1; $c <= $count ; $c++ ) {
									if ( is_active_sidebar( "hootbiz-frontpage-{$areakey}_{$c}" ) ) {
										$displayarea = true;
										break;
									}
								}
								if ( $displayarea ) : ?>
									<div id="frontpage-<?php echo sanitize_html_class( $areakey ); ?>" <?php hootbiz_attr( 'frontpage-area', $areakey, 'frontpage-area frontpage-widgetarea ' . esc_attr( $section_class ) ); ?>>
										<div class="hgrid">
											<?php
											for ( $c = 1; $c <= $count ; $c++ ) {
												$area_id = "frontpage-{$areakey}_{$c}";
												$structurekey = $c - 1;
												?>
												<div id="<?php echo sanitize_html_class( $area_id ); ?>" class="<?php if ( !empty( $structure[$structurekey] ) ) echo sanitize_html_class( $structure[$structurekey] ); ?>">
													<?php
													if ( is_active_sidebar( 'hootbiz-' . $area_id ) )
														dynamic_sidebar( 'hootbiz-' . $area_id );
													?>
												</div>
												<?php
											}
											?>
										</div>
									</div>
								<?php endif;
								break;

							// Display Blog Content
							case 'content-blog':
								wp_reset_postdata(); ?>
								<div id="frontpage-page-content" <?php hootbiz_attr( 'frontpage-area', $key, 'frontpage-area frontpage-pagecontent ' . esc_attr( $section_class ) ); ?>>
									<div class="hgrid hootbiz-blogposts main-content-grid"><?php

										if ( !empty( $section['title'] ) )
											echo '<div class="hgrid-span-12"><h3 class="hootbiz-blogposts-title">' . wp_kses_post( $section['title'] ) . '</h3></div>';

										if ( have_posts() ) :
											$hootbiz_content_layout_class = hootbiz_theme_layout_class( 'content' );
											?>
											<div id="content-archive" class="content <?php echo hootbiz_sanitize_html_classes( $hootbiz_content_layout_class ) ; ?>">
												<div id="content-wrap">
													<?php
													// Template modification Hook
													do_action( 'hootbiz_theme_loop_start', 'frontpage.php' );

													while ( have_posts() ) : the_post();
														// Loads the template-parts/content-{$post_type}.php template.
														hootbiz_get_content_template();
													endwhile;

													// Template modification Hook
													do_action( 'hootbiz_theme_loop_end', 'frontpage.php' );
													?>
												</div>
												<?php
												// Loads the template-parts/loop-nav.php template.
												get_template_part( 'template-parts/loop-nav' );
												?>
											</div>
											<?php hootbiz_get_sidebar( 'primary' ); ?>
										<?php
										else :
											// Loads the template-parts/error.php template.
											get_template_part( 'template-parts/error' );
										endif;
										?>

									</div>
								</div>

								<?php break;

							// Display Page Content
							case 'content-page':
								wp_reset_postdata(); ?>
								<div id="frontpage-page-content" <?php hootbiz_attr( 'frontpage-area', $key, 'frontpage-area frontpage-pagecontent ' . esc_attr( $section_class ) ); ?>>
									<div class="hgrid main-content-grid">

										<?php
										if ( !empty( $section['title'] ) )
											echo '<div class="hgrid-span-12"><h3 class="hootbiz-blogposts-title">' . wp_kses_post( $section['title'] ) . '</h3></div>';

										echo '<div class="hgrid-span-12">';
											echo '<div class="entry-content">';
											// Load the static page content
											while ( have_posts() ) : the_post();
												hootbiz_get_content_template();
											endwhile;
											echo '</div>';
										echo '</div>';
										?>

									</div>
								</div>

								<?php break;

							default:
								// Allow mods to display content
								do_action( 'hootbiz_theme_frontpage_sections', $key, $sections, $section_class, $context );

						endswitch;

					endif;

				endif;
			endforeach;
		endif;

		// Template modification Hook
		do_action( 'hootbiz_theme_main_end', 'frontpage.php' );
		?>

	</main><!-- #content -->

	<?php
	// Template modification Hook
	do_action( 'hootbiz_theme_after_main', 'frontpage.php' );
	?>

	<?php
	if ( $hootbiz_fpg_sidebar !== 'none' ) {
		hootbiz_get_sidebar( 'primary' ); // Loads the template-parts/sidebar-primary.php template.
	}
	?>

</div><!-- .hgrid -->

<?php get_footer(); // Loads the footer.php template. ?>