<?php
/**
 * Upsell page
 *
 * @package    Hoot Business
 * @subpackage Theme
 */

/**
 * Sets up the Appearance Subpage
 *
 * @since 1.0
 * @access public
 * @return void
 */
function hootbiz_theme_add_appearance_subpage() {

	add_theme_page(
		__( 'Hoot Business Premium', 'hoot-business' ),	// Page Title
		__( 'Premium Options', 'hoot-business' ),			// Menu Title
		'edit_theme_options',								// capability
		'hoot-business-premium',							// menu-slug
		'hootbiz_theme_appearance_subpage'						// function name
		);

	add_action( 'admin_enqueue_scripts', 'hootbiz_theme_admin_enqueue_upsell_styles' );

}
/* Add the admin setup function to the 'admin_menu' hook. */
add_action( 'admin_menu', 'hootbiz_theme_add_appearance_subpage' );

/**
 * Enqueue CSS
 *
 * @since 1.0
 * @access public
 * @return void
 */
function hootbiz_theme_admin_enqueue_upsell_styles( $hook ) {
	if ( $hook == 'appearance_page_hoot-business-premium' )
		wp_enqueue_style( 'hootbiz-admin-upsell', hootbiz_data()->incuri . 'admin/css/upsell.css', array(),  hootbiz_data()->hootbiz_version );
}

/**
 * Display the Appearance Subpage
 *
 * @since 1.0
 * @access public
 * @return void
 */
function hootbiz_theme_appearance_subpage() {

	/*** Upsell Copy ***/

	$hootbiz_options_premium = array();
	$imagepath =  esc_url( hootbiz_data()->incuri . 'admin/images/' );

	$hootbiz_cta_top = $hootbiz_cta = '<a class="button button-primary button-buy-premium" href="https://wphoot.com/themes/hoot-business/" target="_blank">' . __( 'Buy Hoot Business Premium', 'hoot-business' ) . '</a>';
	$hootbiz_cta_demo = '<a class="button button-secondary button-view-demo" href="https://demo.wphoot.com/hoot-business/" target="_blank">' . __( 'View Demo Site', 'hoot-business' ) . '</a>';

	$hootbiz_intro = array(
		'name' => __('Upgrade to <span>Hoot Business <strong>Premium</strong></span>', 'hoot-business'),
		'desc' => __("If you've enjoyed using Hoot Business, you're going to love <strong>Hoot Business Premium</strong>.<br>It's a robust upgrade to Hoot Business that gives you many useful features.", 'hoot-business'),
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Complete <br />Style <strong>Customization</strong>', 'hoot-business'),
		'desc' => __('Different looks and styles. Choose from an extensive range of customization features in Hoot Business Premium to setup your own unique front page. Give youe site the personality it deserves.', 'hoot-business'),
		// 'img' => $imagepath . 'premium-style.jpg',
		'style' => 'hero-top',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Unlimited Colors &amp; Backgrounds for Sections', 'hoot-business'),
		'desc' => __('Hoot Business Premium lets you select unlimited colors for different parts of your site. Select pre-existing backgrounds for site sections like topbar, header, footer, page title etc. or upload your own background images/patterns.', 'hoot-business'),
		'img' => $imagepath . 'premium-colors.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Fonts and <span>Typography Control</span>', 'hoot-business'),
		'desc' => __('Assign different typography (fonts, text size, font color) to menu, topbar, logo, content headings, sidebar, footer etc.', 'hoot-business'),
		'img' => $imagepath . 'premium-typography.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Unlimites Sliders, Unlimites Slides', 'hoot-business'),
		'desc' => __('Hoot Business Premium allows you to create unlimited sliders with as many slides as you need using the awesome HootKit plugin.<hr><h4>Add as Shortcodes</h4>You can use these sliders on your Frontpage, or add them anywhere using shortcodes - like in your Posts, Sidebars or Footer.', 'hoot-business'),
		'img' => $imagepath . 'premium-sliders.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('600+ Google Fonts', 'hoot-business'),
		'desc' => __("With the integrated Google Fonts library, you can find the fonts that match your site's personality, and there's over 600 options to choose from.", 'hoot-business'),
		'img' => $imagepath . 'premium-googlefonts.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Image Carousels', 'hoot-business'),
		'desc' => __('Add carousels to your post, in your sidebar, on your frontpage or in your footer. A simple drag and drop interface allows you to easily create and manage carousels.', 'hoot-business'),
		'img' => $imagepath . 'premium-carousels.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __("Floating <br /><span>'Sticky' Header</span> &amp; <span>'Goto Top'</span> button (optional)", 'hoot-business'),
		'desc' => __("The floating header follows the user down your page as they scroll, which means they never have to scroll back up to access your navigation menu, improving user experience.<hr>Or, use the 'Goto Top' button appears on the screen when users scroll down your page, giving them a quick way to go back to the top of the page.", 'hoot-business'),
		'img' => $imagepath . 'premium-header-top.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('One Page <span>Scrolling Website /</span> <span>Landing Page</span>', 'hoot-business'),
		'desc' => __("Make One Page websites with menu items linking to different sections on the page. Watch the scroll animation kick in when a user clicks a menu item to jump to a page section.<hr>Create different landing pages on your site. Change the menu for each page so that the menu items point to sections of the page being displayed.", 'hoot-business'),
		'img' => $imagepath . 'premium-scroller.jpg',
		'style' => 'side',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Additional Blog Layouts (including pinterest <span>type mosaic)</span>', 'hoot-business'),
		'desc' => __('Hoot Business Premium gives you the option to display your post archives in different layouts including a mosaic type layout similar to pinterest.', 'hoot-business'),
		'img' => $imagepath . 'premium-blogstyles.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Custom Widgets', 'hoot-business'),
		'desc' => __('Additional Hootkit Custom widgets crafted and designed specifically for Hoot Business Premium Theme to give you the flexibility of adding stylized content.', 'hoot-business'),
		'img' => $imagepath . 'premium-widgets.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Menu Icons', 'hoot-business'),
		'desc' => __('Select from over 500 icons for your main navigation menu links.', 'hoot-business'),
		'img' => $imagepath . 'premium-menuicons.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Premium Background Patterns (CC0)', 'hoot-business'),
		'desc' => __('Hoot Business Premium comes with many additional premium background patterns. You can always upload your own background image/pattern to match your site design.', 'hoot-business'),
		// 'img' => $imagepath . 'premium-backgrounds.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Automatic Image Lightbox and <span>WordPress Gallery</span>', 'hoot-business'),
		'desc' => __('Automatically open image links on your site with the integrates lightbox in Hoot Business Premium.<hr>Automatically convert standard WordPress galleries to beautiful lightbox gallery slider.', 'hoot-business'),
		'img' => $imagepath . 'premium-lightbox.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Developers <br />love {LESS}', 'hoot-business'),
		'desc' => __('CSS is passe! Developers love the modularity and ease of using LESS, which is why Hoot Business Premium comes with properly organized LESS files for the main stylesheet.', 'hoot-business'),
		'img' => $imagepath . 'premium-lesscss.jpg',
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Easy Import/Export', 'hoot-business'),
		'desc' => __('Moving to a new host? Or applying a new child theme? Easily import/export your customizer settings with just a few clicks - right from the backend.', 'hoot-business'),
		// 'img' => $imagepath . 'premium-import-export.jpg',
		);

	$hootbiz_options_premium[] = array(
		'style' => 'aside',
		'blocks' => array(
			array(
				'name' => __('Custom Javascript &amp; <span>Google Analytics</span>', 'hoot-business'),
				'desc' => __("Easily insert any javascript snippet to your header without modifying the code files. This helps in adding scripts for Google Analytics, Adsense or any other custom code.", 'hoot-business'),
				// 'img' => $imagepath . 'premium-customjs.jpg',
				),
			array(
				'name' => __('Continued <br />Lifetime Updates', 'hoot-business'),
				'desc' => __("You will help support the continued development of Hoot Business - ensuring it works with future versions of WordPress for years to come.", 'hoot-business'),
				// 'img' => $imagepath . 'premium-updates.jpg',
				),
			),
		);

	$hootbiz_options_premium[] = array(
		'name' => __('Premium <br />Priority Support', 'hoot-business'),
		'desc' => __("Need help setting up Hoot Business? Upgrading to Hoot Business Premium gives you prioritized support. We have a growing support team ready to help you with your questions.<hr>Need small modifications? If you are not a developer yourself, you can count on our support staff to help you with CSS snippets to get the look you're after. Best of all, your changes will persist across updates.", 'hoot-business'),
		'img' => $imagepath . 'premium-support.jpg',
		'style' => 'side',
		);

	?>
	<div id="hootbiz-upsell" class="wrap">
		<h1 class="centered"><?php echo $hootbiz_intro['name']; ?></h1>
		<p class="hootbiz-upsell-intro centered"><?php echo $hootbiz_intro['desc']; ?></p>
		<p class="hootbiz-upsell-cta centered"><?php if ( !empty( $hootbiz_cta_demo ) ) echo $hootbiz_cta_demo; echo $hootbiz_cta_top; ?></p>
		<?php if ( !empty( $hootbiz_options_premium ) && is_array( $hootbiz_options_premium ) ): ?>
			<div class="hootbiz-upsell-sub">
				<?php foreach ( $hootbiz_options_premium as $key => $feature ) : ?>
					<?php $style = empty( $feature['style'] ) ? 'info' : $feature['style']; ?>
					<div class="section-premium <?php
						if ( $style == 'hero-top' || $style == 'hero-bottom' ) echo "premium-hero premium-{$style}";
						elseif ( $style == 'side' ) echo 'premium-sideinfo';
						elseif ( $style == 'aside' ) echo 'premium-asideinfo';
						else echo "premium-{$style}";
						?>">

						<?php if ( $style == 'hero-top' || $style == 'hero-bottom' ) : ?>
							<?php if ( $style == 'hero-top' ) : ?>
								<h4 class="heading"><?php echo $feature['name']; ?></h4>
								<?php if ( !empty( $feature['desc'] ) ) echo '<div class="premium-hero-text">' . $feature['desc'] . '</div>'; ?>
							<?php endif; ?>
							<?php if ( !empty( $feature['img'] ) ) : ?>
								<div class="premium-hero-img">
									<img src="<?php echo esc_url( $feature['img'] ); ?>" />
								</div>
							<?php endif; ?>
							<?php if ( $style == 'hero-bottom' ) : ?>
								<h4 class="heading"><?php echo $feature['name']; ?></h4>
								<?php if ( !empty( $feature['desc'] ) ) echo '<div class="premium-hero-text">' . $feature['desc'] . '</div>'; ?>
							<?php endif; ?>

						<?php elseif ( $style == 'side' ) : ?>
							<div class="premium-side-wrap">
								<div class="premium-side-img">
									<img src="<?php echo esc_url( $feature['img'] ); ?>" />
								</div>
								<div class="premium-side-textblock">
									<?php if ( !empty( $feature['name'] ) ) : ?>
										<h4 class="heading"><?php echo $feature['name']; ?></h4>
									<?php endif; ?>
									<?php if ( !empty( $feature['desc'] ) ) echo '<div class="premium-side-text">' . $feature['desc'] . '</div>'; ?>
								</div>
								<div class="clear"></div>
							</div>

						<?php elseif ( $style == 'aside' ) : ?>
							<?php if ( !empty( $feature['blocks'] ) ) : ?>
								<div class="premium-aside-wrap">
								<?php foreach ( $feature['blocks'] as $key => $block ) {
									echo '<div class="premium-aside-block premium-aside-'.($key+1).'">';
										if ( !empty( $block['img'] ) ) : ?>
											<div class="premium-aside-img">
												<img src="<?php echo esc_url( $block['img'] ); ?>" />
											</div>
										<?php endif;
										if ( !empty( $block['name'] ) ) : ?>
											<h4 class="heading"><?php echo $block['name']; ?></h4>
										<?php endif;
										if ( !empty( $block['desc'] ) ) echo '<div class="premium-aside-text">' . $block['desc'] . '</div>';
									echo '</div>';
								} ?>
								<div class="clear"></div>
								</div>
							<?php endif; ?>

						<?php else : ?>
							<?php if ( !empty( $feature['img'] ) ) : ?>
								<div class="premium-info-img">
									<img src="<?php echo esc_url( $feature['img'] ); ?>" />
								</div>
							<?php endif; ?>
							<div class="premium-info-textblock">
								<?php if ( !empty( $feature['name'] ) ) : ?>
									<div class="premium-info-heading"><h4 class="heading"><?php echo $feature['name']; ?></h4></div>
								<?php endif; ?>
								<?php if ( !empty( $feature['desc'] ) ) echo '<div class="premium-info-text">' . $feature['desc'] . '</div>'; ?>
								<div class="clear"></div>
							</div>
						<?php endif; ?>
					</div>
				<?php endforeach; ?>
				<div class="section-premium hootbiz-upsell-cta centered"><?php if ( !empty( $hootbiz_cta_demo ) ) echo $hootbiz_cta_demo; echo $hootbiz_cta; ?></p>
			</div>
		<?php endif; ?>
		<a class="hootbiz-theme-top" href="#wpbody"><span class="dashicons dashicons-arrow-up-alt"></span></a>
	</div>
	<?php
}