<?php
/**
 * Theme Setup
 * This file is loaded using 'after_setup_theme' hook at priority 10
 *
 * @package    Hoot Business
 * @subpackage Theme
 */

/** WordPress **/

// Automatically add <title> to head.
add_theme_support( 'title-tag' );

// Adds core WordPress HTML5 support.
add_theme_support( 'html5', array( 'caption', 'comment-form', 'comment-list', 'gallery', 'search-form' ) );

// Add theme support for WordPress Custom Logo
add_theme_support( 'custom-logo' );

// Add theme support for WordPress Custom Background
add_theme_support( 'custom-background', array( 'default-color' => hootbiz_theme_default_style( 'site_background' ) ) );

// Add theme support for custom headers
add_theme_support( 'custom-header', array( 'width' => 1380, 'height' => 500, 'flex-height' => true, 'flex-width' => true, 'default-image' => hootbiz_data()->template_uri . '/images/header.jpg', ) );

// Adds theme support for WordPress 'featured images'.
add_theme_support( 'post-thumbnails' );

// Automatically add feed links to <head>.
add_theme_support( 'automatic-feed-links' );

// WordPress Jetpack
add_theme_support( 'infinite-scroll', array(
	'type' => apply_filters( 'hootbiz_theme_jetpack_infinitescroll_type', 'click' ), // scroll or click
	'container' => apply_filters( 'hootbiz_theme_jetpack_infinitescroll_container', 'content' ),
	'footer' => false,
	'wrapper' => true,
	'render' => apply_filters( 'hootbiz_theme_jetpack_infinitescroll_render', 'hootbiz_theme_jetpack_infinitescroll_render' ),
) );


/** WooCommerce Plugin **/

// Woocommerce support and init load theme woo functions
if ( class_exists( 'WooCommerce' ) ) {
	add_theme_support( 'woocommerce' );
	if ( file_exists( hootbiz_data()->template_dir . 'woocommerce/functions.php' ) )
		include_once( hootbiz_data()->template_dir . 'woocommerce/functions.php' );
}


/** Hootkit Plugin **/

// Register Hootkit confg settings
add_filter( 'hootkit_register', 'hootbiz_theme_register_hootkit' );

/**
 * Register Hootkit
 *
 * @since 1.0
 * @access public
 * @return string
 */
function hootbiz_theme_register_hootkit( $config ) {
	// Array of configuration settings.
	$config = array(
		'nohoot'    => false,
		'theme_css' => true,
		'modules'   => array(
			'sliders' => array( 'image', ),
			'widgets' => array( 'announce', 'content-blocks', 'content-posts-blocks', 'cta', 'icon', 'post-grid', 'post-list', 'social-icons', 'ticker', ),
		),
	);
	return $config;
}

/* Load theme's Hootkit functions */
if ( class_exists( 'HootKit' ) && file_exists( hootbiz_data()->template_dir . 'hootkit/functions.php' ) )
	include_once( hootbiz_data()->template_dir . 'hootkit/functions.php' );


/** Theme Setup Hooks */

/* Handle content width for embeds and images. Hooked into 'init' so that we can pull custom content width from theme options */
add_action( 'init', 'hootbiz_theme_set_content_width', 10 );

/**
 * Handle content width for embeds and images.
 *
 * @since 1.0
 * @access public
 * @return void
 */
function hootbiz_theme_set_content_width() {
	$width = intval( hootbiz_get_mod( 'site_width' ) );
	$width = !empty( $width ) ? $width : 1260;
	$GLOBALS['content_width'] = absint( $width );
}

/* Modify the '[...]' Read More Text */
add_filter( 'hootbiz_readmoretext', 'hootbiz_theme_readmoretext' );

/**
 * Modify the '[...]' Read More Text
 *
 * @since 1.0
 * @access public
 * @return string
 */
function hootbiz_theme_readmoretext( $more ) {
	$read_more = esc_html( hootbiz_get_mod('read_more') );
	/* Translators: %s is the HTML &rarr; symbol */
	$read_more = ( empty( $read_more ) ) ? sprintf( __( 'Read More %s', 'hoot-business' ), '&rarr;' ) : $read_more;
	return $read_more;
}

/* Modify the exceprt length. Make sure to set the priority correctly such as 999, else the default WordPress filter on this function will run last and override settng here.  */
add_filter( 'excerpt_length', 'hootbiz_theme_custom_excerpt_length', 999 );

/**
 * Modify the exceprt length.
 *
 * @since 1.0
 * @access public
 * @return void
 */
function hootbiz_theme_custom_excerpt_length( $length ) {
	if ( is_admin() )
		return $length;

	$excerpt_length = intval( hootbiz_get_mod('excerpt_length') );
	if ( !empty( $excerpt_length ) )
		return $excerpt_length;
	return 50;
}

/* Register recommended plugins via TGMPA if the extension is available */
add_filter( 'tgmpa_register', 'hootbiz_theme_register_required_plugins' );

/**
 * Register recommended plugins via TGMPA
 *
 * @since 1.0
 * @access public
 * @return string
 */
function hootbiz_theme_register_required_plugins() {
	// Array of plugin arrays. Required keys are name and slug.
	// Since source is from the .org repo, it is not required.
	$plugins = array(
		array(
			'name'     => __( 'HootKit - Widgets &amp; Sliders', 'hoot-business' ),
			'slug'     => 'hootkit',
			'required' => false,
		),
		array(
			'name'     => __( 'Page Builder', 'hoot-business' ),
			'slug'     => 'siteorigin-panels',
			'required' => false,
		),
		array(
			'name'     => __( 'Contact Form', 'hoot-business' ),
			'slug'     => 'contact-form-7',
			'required' => false,
		),
		array(
			'name'     => __( 'Widget Options', 'hoot-business' ),
			'slug'     => 'widget-options',
			'required' => false,
		),
	);
	// Array of configuration settings.
	$config = array(
		'is_automatic' => true,
	);
	// Register plugins with TGM_Plugin_Activation class
	tgmpa( $plugins, $config );
}